@@ -8,40 +8,42 @@ from .Database import DatabaseStatus
 
 
 class Waiter:
-    def __init__(self,executor=None):
-        self._executor=executor
+    def __init__(self, executor=None):
+        self._executor = executor
 
-    def run_query(self,query,database):
+    def run_query(self, query, database):
         pass
 
+
 class WaitWaiter(Waiter):
-    def __init__(self,wait_time,executor=None):
+    def __init__(self, wait_time, executor=None):
         super(WaitWaiter, self).__init__(executor)
-        self._wait_time=wait_time
+        self._wait_time = wait_time
 
-    def run_query(self,query,database):
+    def run_query(self, query, database):
         try:
-            self._executor.run_query(query,database)
+            self._executor.run_query(query, database)
         except django.db.utils.OperationalError:
-            database.status=DatabaseStatus.DOWN
-            self.wait_for_connection(query,database)
+            database.status = DatabaseStatus.DOWN
+            self.wait_for_connection(query, database)
 
-    def wait_for_connection(self, query,database):
+    def wait_for_connection(self, query, database):
         while True:
             time.sleep(self._wait_time)
             try:
                 connections[database.name].connect()
-            except database.operatinal_error:
+            except database.operational_error:
                 pass
             else:
-                self._executor.run_query(query,database)
+                self._executor.run_query(query, database)
                 database.status = DatabaseStatus.RUNNING
                 break
 
+
 class DontWaitWaiter(Waiter):
-    def run_query(self, query,database):
+    def run_query(self, query, database):
         try:
-            self._executor.run_query(query,database)
+            self._executor.run_query(query, database)
         except django.db.utils.OperationalError:
             database.status = DatabaseStatus.DOWN
-            raise django.db.utils.OperationalError
\ No newline at end of file
+            raise django.db.utils.OperationalError
